/*
 * Real-time clock support.
 *
 * Copyright (C) 2023, 2024 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "rtc-jz4780.h"
#include "rtc-defs.h"



// Peripheral abstraction.

Rtc_jz4780_chip::Rtc_jz4780_chip(l4_addr_t addr, Cpm_chip *cpm)
: Rtc_chip(addr, cpm)
{
}

Rtc_chip *jz4780_rtc_chip(l4_addr_t rtc_base, Cpm_chip *cpm)
{
  return new Rtc_jz4780_chip(rtc_base, cpm);
}



// C language interface functions.

void
*jz4780_rtc_init(l4_addr_t rtc_base, void *cpm)
{
  return (void *) jz4780_rtc_chip(rtc_base, static_cast<Cpm_chip *>(cpm));
}

enum Clock_identifiers jz4780_rtc_get_clock(void *rtc)
{
  return static_cast<Rtc_chip *>(rtc)->get_clock();
}

void jz4780_rtc_disable(void *rtc)
{
  static_cast<Rtc_chip *>(rtc)->disable();
}

void jz4780_rtc_enable(void *rtc)
{
  static_cast<Rtc_chip *>(rtc)->enable();
}

void jz4780_rtc_alarm_disable(void *rtc)
{
  static_cast<Rtc_chip *>(rtc)->alarm_disable();
}

void jz4780_rtc_alarm_enable(void *rtc)
{
  static_cast<Rtc_chip *>(rtc)->alarm_enable();
}

uint32_t jz4780_rtc_get_seconds(void *rtc)
{
  return static_cast<Rtc_chip *>(rtc)->get_seconds();
}

void jz4780_rtc_set_seconds(void *rtc, uint32_t seconds)
{
  static_cast<Rtc_chip *>(rtc)->set_seconds(seconds);
}

uint32_t jz4780_rtc_get_alarm_seconds(void *rtc)
{
  return static_cast<Rtc_chip *>(rtc)->get_alarm_seconds();
}

void jz4780_rtc_set_alarm_seconds(void *rtc, uint32_t seconds)
{
  static_cast<Rtc_chip *>(rtc)->set_alarm_seconds(seconds);
}

void jz4780_rtc_set_regulator(void *rtc, uint32_t base, uint32_t adjustment)
{
  static_cast<Rtc_chip *>(rtc)->set_regulator(base, adjustment);
}

void jz4780_rtc_hibernate(void *rtc)
{
  static_cast<Rtc_chip *>(rtc)->hibernate();
}

void jz4780_rtc_power_down(void *rtc)
{
  static_cast<Rtc_chip *>(rtc)->power_down();
}
